close all; clear all; clc
addpath( genpath('conv_opt'), '-end' );
addpath( genpath('functions') );
addpath( genpath('images'), '-end' );

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% PARAMETER SELECTION %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% image name
image_name  = 'corridor';   % corridor, teddy or venus

% algorithmic parameters
opt.nit     = 1000;

% Uncomment and fix your parameter or comment to use the default ones
% opt.eta     =  5.8637e+03; % TV
% opt.minDisp = 0;
% opt.maxDisp = 12;

% Evaluation parameter
coef              = 2;

% regularization parameter
opt.error_measure = 'l1';
opt.regul         = 'tv';
opt.tol           =  10^-4;                 % stopping criterion (you may set 10^-4 for faster, but less accurate, results)
opt.show          =  @(x) imshow(x,[]);     % function handler to show something every 10 iterations
opt.weights       =  [100, 200, 10];

%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% RUN THE SIMULATION %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%

% print info
fprintf('\n %s \n', image_name); for mm = 1:length(image_name)+2, fprintf('='); end, fprintf('\n');

% original image
[image, opt] = get_image(image_name, opt);

%%
% Optimization
[x_disp, mask, it, time, cost] = estimate_disp(image, opt);

fprintf(' (EPP, MAE) = (%2.2f, %2.2f) --> it: %d, time: %3.2f, eta %d \n', EPP(x_disp, image.true, mask, coef), MAE(x_disp, image.true), it, time(end), opt.eta);

figure
subplot(221), imagesc(image.left);  colormap gray; axis off; title('left image');
subplot(222), imagesc(image.right); colormap gray; axis off; title('Right image');
subplot(223), imagesc(image.true);  colormap gray; axis off; title('Ground truth');
subplot(224), imagesc(x_disp);      colormap gray; axis off; title('Our result');

